import { type FetchAdapter, type Logger } from '@agentuity/adapter';
export type { Logger } from '@agentuity/adapter';
export { createMinimalLogger } from './logger.ts';
export { ListParamsSchema, PaginatedListSchema, PaginationParamsSchema, SortDirectionSchema, SortParamsSchema, type ListParams, type PaginatedList, type PaginationParams, type SortDirection, type SortParams, } from './pagination.ts';
export declare function isLogger(val: unknown): val is Logger;
export declare function resolveApiKey(apiKey?: string): string | undefined;
export declare function resolveRegion(): string;
export declare function resolveServiceUrl(options: {
    url?: string;
    envKey: string;
    fallback: string;
}): string;
export interface ServiceAdapterOptions {
    apiKey?: string;
    orgId?: string;
    logger?: Logger;
}
export declare function createServiceAdapter(options?: ServiceAdapterOptions): {
    adapter: FetchAdapter;
    logger: Logger;
};
//# sourceMappingURL=index.d.ts.map